==> RsSmw-4.90.49.53-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Wlnn/Fblock/TdWindowing/State.py <==
from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:TDWindowing:STATe \n
		Snippet: driver.source.bb.wlnn.fblock.tdWindowing.state.set(state = False, frameBlock = repcap.FrameBlock.Default) \n
		Activates/deactivates the time domain windowing. Time domain windowing is a method to influence the spectral
		characteristics of the signal, which is not stipulated by the standard. However, it does not replace oversampling and
		subsequent signal filtering. \n
			:param state: 0| 1| OFF| ON
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
		"""
		param = Conversions.bool_to_str(state)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:TDWindowing:STATe {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:TDWindowing:STATe \n
		Snippet: value: bool = driver.source.bb.wlnn.fblock.tdWindowing.state.get(frameBlock = repcap.FrameBlock.Default) \n
		Activates/deactivates the time domain windowing. Time domain windowing is a method to influence the spectral
		characteristics of the signal, which is not stipulated by the standard. However, it does not replace oversampling and
		subsequent signal filtering. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: state: 0| 1| OFF| ON"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:TDWindowing:STATe?')
		return Conversions.str_to_bool(response)

==> RsSmw-5.0.44.58-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Wlnn/Fblock/TdWindowing/State.py <==
from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:TDWindowing:STATe \n
		Snippet: driver.source.bb.wlnn.fblock.tdWindowing.state.set(state = False, frameBlock = repcap.FrameBlock.Default) \n
		Activates/deactivates the time domain windowing. Time domain windowing is a method to influence the spectral
		characteristics of the signal, which is not stipulated by the standard. However, it does not replace oversampling and
		subsequent signal filtering. \n
			:param state: 1| ON| 0| OFF
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
		"""
		param = Conversions.bool_to_str(state)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:TDWindowing:STATe {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:TDWindowing:STATe \n
		Snippet: value: bool = driver.source.bb.wlnn.fblock.tdWindowing.state.get(frameBlock = repcap.FrameBlock.Default) \n
		Activates/deactivates the time domain windowing. Time domain windowing is a method to influence the spectral
		characteristics of the signal, which is not stipulated by the standard. However, it does not replace oversampling and
		subsequent signal filtering. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: state: 1| ON| 0| OFF"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:TDWindowing:STATe?')
		return Conversions.str_to_bool(response)
